@@ -13,9 +13,9 @@ import java.util.ArrayList;
 import java.util.List;
 
 import org.gnu.gdk.Pixbuf;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.glib.Value;
-import org.gnu.glib.Handle;
 
 /**
  * The TreeStore is a Model used for storing data which will be displayed in any
@@ -347,9 +347,9 @@ public class TreeStore extends TreeModel implements TreeSortable, TreeDragDest,
      *            The value to be set.
      */
     public void setValue(TreeIter iter, DataColumnPixbuf dataBlock,
-            org.gnu.gdk.Pixbuf value) {
-        Value val = new Value(Type.PIXBUF());
-        val.setPixbuf(value);
+            Pixbuf value) {
+        Value val = new Value(Type.OBJECT());
+        val.setJavaObject(value);
         gtk_tree_store_set_value(getHandle(), iter.getHandle(), dataBlock
                 .getColumn(), val.getHandle());
     }
