@@ -11,7 +11,9 @@
 #include <string.h>
 #include <atk/atk.h>
 #include "jg_jnu.h"
+#include "gtk_java.h"
 
+#include "org_gnu_atk_StateType.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -29,7 +31,7 @@ JNIEXPORT jbyteArray JNICALL Java_org_gnu_atk_StateType_atk_1state_1type_1get_1n
     jsize result_len = result_g ? strlen (result_g) : 0;
     jbyteArray result_j = result_g ? (*env)->NewByteArray (env, result_len) : NULL;
     if (result_g) 
-    	(*env)->SetByteArrayRegion (env, result_j, 0, result_len, result_g);
+    	(*env)->SetByteArrayRegion (env, result_j, 0, result_len, (jbyte *)result_g);
     return result_j;
 }
 
